@@ -1,5 +1,8 @@
 # frozen_string_literal: true
 
+# Released under the MIT License.
+# Copyright, 2020-2022, by Samuel Williams.
+
 source "https://rubygems.org"
 
 # Specify your gem's dependencies in console.gemspec
@@ -12,3 +15,8 @@ group :maintenance, optional: true do
 	gem "bake-github-pages"
 	gem "utopia-project"
 end
+
+group :test do
+	gem "bake-test"
+	gem "bake-test-external"
+end
